gtk+ r21774 - in trunk: . gtk
- From: mitch svn gnome org
- To: svn-commits-list gnome org
- Subject: gtk+ r21774 - in trunk: . gtk
- Date: Fri, 7 Nov 2008 16:50:29 +0000 (UTC)
Author: mitch
Date: Fri Nov 7 16:50:29 2008
New Revision: 21774
URL: http://svn.gnome.org/viewvc/gtk+?rev=21774&view=rev
Log:
2008-11-07 Michael Natterer <mitch imendio com>
* gtk/gtkpaned.c: argh, actually call the newly added private
gtk_paned_calc_position() instead of the deprecated public
version.
Modified:
trunk/ChangeLog
trunk/gtk/gtkpaned.c
Modified: trunk/gtk/gtkpaned.c
==============================================================================
--- trunk/gtk/gtkpaned.c (original)
+++ trunk/gtk/gtkpaned.c Fri Nov 7 16:50:29 2008
@@ -843,12 +843,12 @@
if (paned->priv->orientation == GTK_ORIENTATION_HORIZONTAL)
{
- gtk_paned_compute_position (paned,
- MAX (1, widget->allocation.width
- - handle_size
- - 2 * border_width),
- child1_requisition.width,
- child2_requisition.width);
+ gtk_paned_calc_position (paned,
+ MAX (1, widget->allocation.width
+ - handle_size
+ - 2 * border_width),
+ child1_requisition.width,
+ child2_requisition.width);
paned->handle_pos.x = widget->allocation.x + paned->child1_size + border_width;
paned->handle_pos.y = widget->allocation.y + border_width;
@@ -872,12 +872,12 @@
}
else
{
- gtk_paned_compute_position (paned,
- MAX (1, widget->allocation.height
- - handle_size
- - 2 * border_width),
- child1_requisition.height,
- child2_requisition.height);
+ gtk_paned_calc_position (paned,
+ MAX (1, widget->allocation.height
+ - handle_size
+ - 2 * border_width),
+ child1_requisition.height,
+ child2_requisition.height);
paned->handle_pos.x = widget->allocation.x + border_width;
paned->handle_pos.y = widget->allocation.y + paned->child1_size + border_width;
@@ -1501,7 +1501,7 @@
* if the total allocation changes at the same time
* as the position, the position set is with reference
* to the new total size. If only the position changes,
* then clamping will occur in gtk_paned_compute_position()
*/
paned->child1_size = position;
[
@@ -1501,7 +1501,7 @@
* as the position, the position set is with reference
* to the new total size. If only the position changes,
- * then clamping will occur in gtk_paned_compute_position()
+ * then clamping will occur in gtk_paned_calc_position()
*/
paned->child1_size = position;
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]